import React, { useEffect, useState, useCallback } from 'react';
import { useHistory } from 'react-router-dom';
import queryString from 'qs';
import { useConfig } from '../../../utilities/Config';
import { useAuth } from '../../../utilities/Auth';
import usePayloadAPI from '../../../../hooks/usePayloadAPI';
import DefaultList from './Default';
import RenderCustomComponent from '../../../utilities/RenderCustomComponent';
import { useStepNav } from '../../../elements/StepNav';
import formatFields from './formatFields';
import buildColumns from './buildColumns';
import { usePreferences } from '../../../utilities/Preferences';
import { useSearchParams } from '../../../utilities/SearchParams';
import getInitialColumns from './getInitialColumns';
const ListView = (props) => {
    var _a, _b;
    const { collection, collection: { slug, labels: { plural, }, admin: { useAsTitle, defaultColumns, pagination: { defaultLimit, }, components: { views: { List: CustomList, } = {}, } = {}, }, }, } = props;
    const { serverURL, routes: { api, admin } } = useConfig();
    const preferenceKey = `${collection.slug}-list`;
    const { permissions } = useAuth();
    const { setStepNav } = useStepNav();
    const { getPreference, setPreference } = usePreferences();
    const { page, sort, limit, where } = useSearchParams();
    const history = useHistory();
    const [fetchURL, setFetchURL] = useState('');
    const [fields] = useState(() => formatFields(collection));
    const [tableColumns, setTableColumns] = useState(() => {
        const initialColumns = getInitialColumns(fields, useAsTitle, defaultColumns);
        return buildColumns(collection, initialColumns);
    });
    const collectionPermissions = (_a = permissions === null || permissions === void 0 ? void 0 : permissions.collections) === null || _a === void 0 ? void 0 : _a[slug];
    const hasCreatePermission = (_b = collectionPermissions === null || collectionPermissions === void 0 ? void 0 : collectionPermissions.create) === null || _b === void 0 ? void 0 : _b.permission;
    const newDocumentURL = `${admin}/collections/${slug}/create`;
    const [{ data }, { setParams: setFetchParams }] = usePayloadAPI(fetchURL, { initialParams: { page: 1 } });
    const activeColumnNames = tableColumns.map(({ accessor }) => accessor);
    const stringifiedActiveColumns = JSON.stringify(activeColumnNames);
    useEffect(() => {
        setStepNav([
            {
                label: plural,
            },
        ]);
    }, [setStepNav, plural]);
    // /////////////////////////////////////
    // Set up Payload REST API query params
    // /////////////////////////////////////
    useEffect(() => {
        const params = {
            depth: 0,
            draft: 'true',
            page: undefined,
            sort: undefined,
            where: undefined,
            limit,
        };
        if (page)
            params.page = page;
        if (sort)
            params.sort = sort;
        if (where)
            params.where = where;
        // Performance enhancement
        // Setting the Fetch URL this way
        // prevents a double-fetch
        setFetchURL(`${serverURL}${api}/${slug}`);
        setFetchParams(params);
    }, [setFetchParams, page, sort, where, collection, getPreference, limit, serverURL, api, slug]);
    // /////////////////////////////////////
    // Fetch preferences on first load
    // /////////////////////////////////////
    useEffect(() => {
        (async () => {
            const currentPreferences = await getPreference(preferenceKey);
            if (currentPreferences === null || currentPreferences === void 0 ? void 0 : currentPreferences.columns) {
                setTableColumns(buildColumns(collection, currentPreferences === null || currentPreferences === void 0 ? void 0 : currentPreferences.columns));
            }
            const params = queryString.parse(history.location.search, { ignoreQueryPrefix: true, depth: 0 });
            const search = {
                ...params,
                sort: (params === null || params === void 0 ? void 0 : params.sort) || (currentPreferences === null || currentPreferences === void 0 ? void 0 : currentPreferences.sort),
                limit: (params === null || params === void 0 ? void 0 : params.limit) || (currentPreferences === null || currentPreferences === void 0 ? void 0 : currentPreferences.limit),
            };
            const newSearchQuery = queryString.stringify(search, { addQueryPrefix: true });
            if (newSearchQuery.length > 1) {
                history.replace({
                    search: newSearchQuery,
                });
            }
        })();
    }, [collection, getPreference, preferenceKey, history]);
    // /////////////////////////////////////
    // When any preference-enabled values are updated,
    // Set preferences
    // /////////////////////////////////////
    useEffect(() => {
        const newPreferences = {
            limit,
            sort,
            columns: JSON.parse(stringifiedActiveColumns),
        };
        setPreference(preferenceKey, newPreferences);
    }, [sort, limit, stringifiedActiveColumns, preferenceKey, setPreference]);
    const setActiveColumns = useCallback((columns) => {
        setTableColumns(buildColumns(collection, columns));
    }, [collection]);
    return (React.createElement(RenderCustomComponent, { DefaultComponent: DefaultList, CustomComponent: CustomList, componentProps: {
            collection: { ...collection, fields },
            newDocumentURL,
            hasCreatePermission,
            data,
            tableColumns,
            columnNames: activeColumnNames,
            setColumns: setActiveColumns,
            limit: limit || defaultLimit,
        } }));
};
export default ListView;
